<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=vi
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aide_non_disponible' => 'Phần giúp đỡ này chưa được dịch sang ngôn ngữ này.',
	'avis_acces_interdit' => 'Quý vị không có quyền vào đây.',
	'avis_article_modifie' => 'Coi chừng, @nom_auteur_modif@ vừa sửa bài này cách đây @date_diff@ phút',
	'avis_aucun_resultat' => 'Không có kết quả.',
	'avis_chemin_invalide_1' => 'Hướng đi mà bạn đã chọn',
	'avis_chemin_invalide_2' => 'dường như không đúng. Xin vui lòng trở lại trang trước và xem lại các dữ kiện cung cấp.',
	'avis_connexion_echec_1' => 'Không nối vào SQL được.', # MODIF
	'avis_connexion_echec_2' => 'Trở lại trang trước và kiểm lại các dữ kiện vừa cho vào.',
	'avis_connexion_echec_3' => '<b>T.B.</b> Trong một số server, bạn phải <b>yêu cầu</b> quyền được sử dụng SQL database trước khi dùng. Nếu bạn không nối vào được, hãy xem lại coi bạn có yêu cầu chưa.', # MODIF
	'avis_connexion_ldap_echec_1' => 'Không nối vào LDAP server được.',
	'avis_connexion_ldap_echec_2' => 'Trở lại trang trước và xem lại các dữ kiện đã cung cấp.',
	'avis_connexion_ldap_echec_3' => 'Một cách khác, đừng dùng LDAP support để đem tên người dùng vào.',
	'avis_deplacement_rubrique' => 'LƯU Ý! Đề mục này chứa @contient_breves@ các tin ngắn @scb@: nếu bạn dời nó đi, xin đánh dấu vào ô này để xác nhận.',
	'avis_erreur_connexion_mysql' => 'Có Lỗi-không nối với SQL',
	'avis_espace_interdit' => '<b>Vùng cấm địa</b><p>SPIP đã được thiết trí rồi.',
	'avis_lecture_noms_bases_1' => 'Nhu liệu thiết trí không đọc được tên của database thiết trí.',
	'avis_lecture_noms_bases_2' => 'Không có database nào hết, hoặc đặc điểm cho phép liệt kê tên database bị tắt đi vì lý do an ninh (thường là như vậy cho nhiều máy chủ)',
	'avis_lecture_noms_bases_3' => 'Trong trường hợp lựa chọn thứ nhì xảy ra, sau khi bạn login vào, có thể một database có tên lúc đó có thể dùng được: ',
	'avis_non_acces_page' => 'Bạn không có quyền vào trang này.',
	'avis_operation_echec' => 'Thao tác thất bại.',
	'avis_suppression_base' => 'BÁO ĐỘNG, xóa dữ kiện rồi sẽ không lấy lại được',

	// B
	'bouton_acces_ldap' => 'Thêm hồ sơ vào LDAP >>',
	'bouton_ajouter' => 'Thêm',
	'bouton_demande_publication' => 'Đề nghị bài này cho ban biên tập',
	'bouton_effacer_tout' => 'Xoá TẤT CẢ',
	'bouton_envoyer_message' => 'Tin thư đầy đủ: Gửi đi ',
	'bouton_modifier' => 'Thay đổi',
	'bouton_radio_afficher' => 'Hiển thị',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Hiện tên ra',
	'bouton_radio_envoi_annonces_adresse' => 'Gửi thông báo đến địa chỉ:',
	'bouton_radio_envoi_liste_nouveautes' => 'Gửi các tin tức mới nhất',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Không hiện tên ra  ',
	'bouton_radio_non_envoi_annonces_editoriales' => 'Đừng gửi bất cứ thông báo xã luận nào',
	'bouton_redirection' => 'CHUYỂN TỚI',
	'bouton_relancer_installation' => 'Thiết trí lại',
	'bouton_suivant' => 'Kế tiếp',
	'bouton_tenter_recuperation' => 'Tìm cách sửa chữa',
	'bouton_test_proxy' => 'Thử nghiệm proxy',
	'bouton_vider_cache' => 'Làm sạch cache',

	// C
	'cache_modifiable_webmestre' => 'Webmaster có thể điều chỉnh các thông số này.',
	'calendrier_synchro' => 'Nếu bạn có thiết trí nhu liệu nhật ký tương ứng với <b>iCal</b>, bạn có thể đồng bộ hóa nó với trang web.',

	// D
	'date_mot_heures' => 'Giờ',

	// E
	'email' => 'Ðiện thư',
	'email_2' => 'Ðiện thư:',
	'entree_adresse_annuaire' => 'Địa chỉ ngăn',
	'entree_adresse_email' => 'Điạ chỉ email của bạn',
	'entree_base_donnee_1' => 'Địa chỉ database',
	'entree_base_donnee_2' => '(Thông thường, địa chỉ này giống địa chỉ website của bạn, đôi khi nó mang tên «localhost», và có khi nó để trống.)',
	'entree_biographie' => 'Tiểu sử ngắn gọn (một vài chữ).',
	'entree_chemin_acces' => '<b>Xin cho biết</b> tên ngăn:',
	'entree_cle_pgp' => 'Khóa PGP của bạn',
	'entree_contenu_rubrique' => '(Mô tả ngắn gọn nội dung của đề mục)',
	'entree_identifiants_connexion' => 'Tên gọi lúc nối vào của bạn...',
	'entree_informations_connexion_ldap' => 'Xin điền vào mẫu này với các dữ kiện móc nối LDAP. Bạn sẽ được người quản lý mạng hoặc hệ điều hành cho biết các dữ kiện này.',
	'entree_infos_perso' => 'Bạn là ai?',
	'entree_interieur_rubrique' => 'Trong đề mục:',
	'entree_liens_sites' => '<b>Điểm nối hypertext</b> (tham khảo, website đến viếng...)',
	'entree_login' => 'Login của bạn',
	'entree_login_connexion_1' => 'Nối vào',
	'entree_login_connexion_2' => '(Đôi khi giống với ký danh FTP của bạn và đôi khi để trống)',
	'entree_mot_passe' => 'Mật mã của bạn',
	'entree_mot_passe_1' => 'Mật mã để nối vào',
	'entree_mot_passe_2' => '(Đôi khi giống mật mã FTP của bạn và đôi khi để trống)',
	'entree_nom_fichier' => 'Xin điền tên hồ sơ @texte_compresse@:',
	'entree_nom_pseudo' => 'Tên hoặc bí danh của bạn',
	'entree_nom_pseudo_1' => '(Tên hay bí danh của bạn)',
	'entree_nom_site' => 'Tên website của bạn',
	'entree_nouveau_passe' => 'Mật mã mới',
	'entree_passe_ldap' => 'Mật mã',
	'entree_port_annuaire' => 'Số cổng của thư mục',
	'entree_signature' => 'Chữ ký',
	'entree_titre_obligatoire' => '<b>Tựa đề</b> [Bắt buộc]<br />',
	'entree_url' => 'Địa chỉ website của bạn',

	// I
	'ical_info1' => 'Trang này cho bạn biết các cách để theo dõi các hoạt động của trang web này.',
	'ical_info2' => 'Để biết thêm chi tiết xin vào xem trang web <a href="@spipnet@">SPIP’s documentation</a>.', # MODIF
	'ical_info_calendrier' => 'Bạn có 2 thời biểu để sử dụng. Thời biểu thứ nhất liệt kê tất cả các bài viết được đăng. Thời biểu thứ hai liệt kê các thông báo của Ban Biên Tập và những thông tin cá nhân của bạn. Phần này được dành cho bạn qua một mật mã riêng mà bạn có thể thay đổi bằng cách thay đổi mật mã của mình.',
	'ical_methode_http' => 'Đang tải xuống',
	'ical_methode_webcal' => 'Đồng bộ hoá (webcal://)', # MODIF
	'ical_texte_js' => 'Một mệnh lệnh javascript có thể được sử dụng để hiển thị những bài vỡ mới nhất được đăng của trang web này trên bất kỳ trang web nào của bạn một cách rất dễ dàng.',
	'ical_texte_prive' => 'Thời biểu này, với tính cách cá nhân, sẽ cho bạn biết các hoạt động cá nhân của Ban Biên Tập (công việc, các cuộc hẹn, các bài đã nộp và các tin tức...).',
	'ical_texte_public' => 'Thời biểu này giúp bạn theo dõi các hoạt động chung của trang web (các bài viết và các tin tức đã được đăng).',
	'ical_texte_rss' => 'Bạn có thể động bộ hoá các tin tức mới nhất của trang web này bằng bất kỳ hệ thống đọc dạng XML/RSS (Rich Site Summary) nào. XML/RSS cũng là dạng hồ sơ mà SPIP có thể dùng để đọc các tin tức mới nhất đăng tải bởi các trang web dùng cùng một hệ trao đổi tương ứng.',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Mailing-list',
	'ical_titre_rss' => 'Hồ sơ «Backend»', # MODIF
	'icone_activer_cookie' => 'Dùng Cookie',
	'icone_afficher_auteurs' => 'Trình bày tên tác giả ',
	'icone_afficher_visiteurs' => 'Trình bày số độc giả',
	'icone_arret_discussion' => 'Không tham gia vào cuộc thảo luận này nữa',
	'icone_calendrier' => 'Lịch',
	'icone_creer_auteur' => 'Thêm tên một tác giả mới và ghi vào bài này',
	'icone_creer_mot_cle' => 'Thêm một từ then chốt mới và ghi vào bài này',
	'icone_creer_rubrique_2' => 'Thêm một đề mục mới ',
	'icone_modifier_article' => 'Sửa bài này',
	'icone_modifier_rubrique' => 'Sửa đề mục này',
	'icone_retour' => 'Trở lại',
	'icone_retour_article' => 'Trở về bài trước',
	'icone_supprimer_cookie' => 'xóa bỏ cookie',
	'icone_supprimer_rubrique' => 'Xoá đề mục này',
	'icone_supprimer_signature' => 'Xoá chữ ký này',
	'icone_valider_signature' => 'Chấp thuận',
	'image_administrer_rubrique' => 'Bạn có thể quản trị đề mục này',
	'info_1_article' => '1 bài',
	'info_activer_cookie' => 'Bạn có thể cho chạy <b>administration cookie</b> để bạn có thể qua lại giữa trang web công cộng và khu vực riêng.',
	'info_administrateur' => 'Quản lý',
	'info_administrateur_1' => 'Quản lý',
	'info_administrateur_2' => 'của trang web (<i>sử dụng cẩn thận</i>)',
	'info_administrateur_site_01' => 'Nếu bạn là quản trị viên của website, xin',
	'info_administrateur_site_02' => 'Bấm vào điểm nối này',
	'info_administrateurs' => 'Những người quản lý',
	'info_administrer_rubrique' => 'Bạn có thể quản trị đề mục này',
	'info_adresse' => 'đến địa chỉ:',
	'info_adresse_url' => 'Địa chỉ trang web của bạn',
	'info_aide_en_ligne' => 'Giúp đỡ SPIP online',
	'info_ajout_image' => 'Khi bạn đính kèm hình (trong dạng hồ sơ) vào một bài, SPIP có thể tự động chế ra các hình mẫu để xem trước (tức thumbnails) từ tấm hình nguyên thủy. Với đặc điểm này có thể tự động thiết lập ra một tập/bộ hình ảnh, album.',
	'info_ajouter_rubrique' => 'Thêm một đề mục khác để quản trị:',
	'info_annonce_nouveautes' => 'Thông tin mới nhất',
	'info_article' => 'bài',
	'info_article_2' => 'bài',
	'info_article_a_paraitre' => 'Những bài đã đề ngày để phát hành',
	'info_articles_02' => ' bài',
	'info_articles_2' => 'Bài',
	'info_articles_auteur' => 'Bài của tác giả này',
	'info_articles_trouves' => 'Những bài tìm thấy',
	'info_attente_validation' => 'Bài vở của bạn đang chờ thông qua',
	'info_aujourdhui' => 'hôm nay:',
	'info_auteurs' => 'Tác giả',
	'info_auteurs_par_tri' => 'Tác giả@partri@',
	'info_auteurs_trouves' => 'Những tác giả tìm thấy',
	'info_authentification_externe' => 'Xác nhận từ bên ngoài',
	'info_avertissement' => 'Báo động',
	'info_base_installee' => 'Cấu trúc database của bạn đã được thiết trí.',
	'info_chapeau' => 'Dẫn nhập',
	'info_chapeau_2' => 'Dẫn nhập:',
	'info_chemin_acces_1' => ' Chọn lựa: <b>ngõ vào trong thư mục</b>',
	'info_chemin_acces_2' => 'Từ đây trở đi, bạn phải cấu tạo lối vào thông tin thư mục. Dữ kiện này cần thiết để đọc hồ sơ người sử dụng trong danh bạ.',
	'info_chemin_acces_annuaire' => 'Chọn lựa: <b>ngõ vào trong thư mục</b>',
	'info_choix_base' => 'Bước thứ ba:',
	'info_classement_1' => ' trong số @liste@',
	'info_classement_2' => ' trong số @liste@',
	'info_code_acces' => 'Đừng quên mã số để vào của bạn!',
	'info_config_suivi' => 'Nếu địa chỉ này là của một mailing list,  bạn cho biết địa chỉ để ghi danh. Địa chỉ ghi danh có thể là URL (thí dụ trang ghi danh qua web), hay địa chỉ email có ghi rõ tựa đề (subject). Thí dụ: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Bạn có thể ghi danh vào mailing list dưới đây, nếu bạn muốn nhận thông tin các bài được nộp vào trang web này.',
	'info_confirmer_passe' => 'Xác nhận lại mật mã mới:',
	'info_connexion_base' => 'Bước thứ nhì: <b>thử nối vào database</b>',
	'info_connexion_ldap_ok' => 'Nối vào LDAP tốt đẹp.</b><p> Bạn có thể qua bước kế tiếp.</p>', # MODIF
	'info_connexion_mysql' => 'Bước thứ nhất: <b>Nối vào SQL của bạn</b>',
	'info_connexion_ok' => 'Nối vào tốt đẹp.',
	'info_contact' => 'Liên lạc',
	'info_contenu_articles' => 'Nội dung bài',
	'info_creation_paragraphe' => '(Để bắt đầu đoạn văn mới, bạn chỉ cần chừa hàng trống)', # MODIF
	'info_creation_rubrique' => 'Trước khi được phép viết một bài mới, bạn phải lập ra ít nhất một đề mục.',
	'info_creation_tables' => 'Bước thứ tư: <b>Tạo lập ra các bảng trong database</b>',
	'info_creer_base' => '<b>Tạo lập</b> ra một database mới:',
	'info_dans_rubrique' => 'Trong đề mục:',
	'info_date_publication_anterieure' => 'Ngày tháng của bài đã đăng:',
	'info_date_referencement' => 'NGÀY NỐI KẾT WEBSITE NÀY:',
	'info_derniere_etape' => 'Bước chót: <b>Hoàn tất!</b>',
	'info_descriptif' => 'Tóm lược:',
	'info_discussion_cours' => 'Đang trao đổi',
	'info_ecrire_article' => 'Để có thể soạn một bài vở, bạn phải lập ra một đề mục trước đã. <Trước khi có thể viết bài, bạn phải lập ra ít nhất một đề mục.',
	'info_email_envoi' => 'Địa chỉ email của người gửi (không bắt buộc)',
	'info_email_envoi_txt' => 'Đánh vào địa chỉ người gửi để gửi email (theo định sẵn, thì địa chỉ người nhận sẽ được dùng làm địa chỉ gửi) :',
	'info_email_webmestre' => 'Địa chỉ email của webmaster (không bắt buộc) ', # MODIF
	'info_envoi_email_automatique' => 'Gửi email tự động',
	'info_envoyer_maintenant' => 'Gửi bây giờ',
	'info_etape_suivante' => 'Qua bước kế',
	'info_etape_suivante_1' => 'Bạn có thể qua bước kế tiếp.',
	'info_etape_suivante_2' => ' Bạn có thể qua bước kế tiếp.',
	'info_exportation_base' => 'Đem database ra ngoài vào @archive@',
	'info_facilite_suivi_activite' => 'Để làm nhẹ công việc của Ban Biên Tập, SPIP gửi bằng email các thông báo xin phép đăng và chấp thuận bài vở (đến mailing list của chủ bút chẳng hạn) ',
	'info_fichiers_authent' => 'Hồ sơ xác nhận ".htpasswd"',
	'info_forums_abo_invites' => 'Trang web có các diễn đàn cần ghi danh; khách có thể vào ghi danh ở trang công cộng.',
	'info_gauche_admin_tech' => '<b>Chỉ có quản trị viên được phép vào trang này.</b><p> Nơi đây cho phép bạn thực hiện một số công việc bảo trì. Một số việc cần phải có chứng nhận đặc biệt, cần phải dùng FTP để vào trang web.</p>', # MODIF
	'info_gauche_admin_vider' => '<b>Chỉ có quản trị viên được phép vào trang này.</b><p> Nơi đây cho phép bạn thực hiện một số công việc bảo trì. Một số việc cần phải có chứng nhận đặc biệt, và cần phải dùng FTP để vào trang web.</p>', # MODIF
	'info_gauche_auteurs' => 'Danh sách tất cả tác giả được liệt kê nơi đây. Trách nhiệm của mỗi người được biểu hiện qua màu của icon (chủ bút=màu xanh lá cây; quản lý=màu vàng).',
	'info_gauche_auteurs_exterieurs' => 'Các tác giả bên ngoài (không được phép vào trang web) được biểu hiện bằng icon màu xanh dương; Tác giả nào bị xóa tên được biểu hiện bằng icon thùng rác.', # MODIF
	'info_gauche_messagerie' => 'Phương tiện thư tín cho phép bạn trao đổi thư tín giữa các chủ bút với nhau, lưu trữ bản ghi nhớ (để sử dụng riêng) hoặc hiển thị thông báo trên trang nhà của vùng riêng (nếu bạn là người quản trị).',
	'info_gauche_statistiques_referers' => 'Trang này liệt kê danh sách <i>referrers</i>, tức là các trang có chứa điểm nối đến trang của bạn, chỉ cho hôm nay mà thôi: thật ra danh sách này được soạn mỗi 24 giờ.',
	'info_gauche_visiteurs_enregistres' => 'Danh sách những người khách ghi danh trong vùng công cộng của trang web (theo diễn đàn)',
	'info_generation_miniatures_images' => 'Hình mẫu xem trước (thumbnail)',
	'info_hebergeur_desactiver_envoi_email' => 'Một số máy chủ không cho phép gửi email tự động từ server. Trong trường hợp này, những đặc điểm sau đây của SPIP không thể thiết lập được.',
	'info_hier' => 'hôm qua: ',
	'info_identification_publique' => 'Danh tánh công cộng của bạn...',
	'info_image_process' => 'Xin chọn cách tạo ra hình trang trí bằng bấm trên hình đẹp nhất.',
	'info_image_process2' => '<b>N.B.</b> <i>Nếu bạn không thấy hình nào cả có nghĩa là máy chủ chưa được thiết trí để sử dụng hình. Nếu bạn muốn dùng hình, liên lạc với nhóm phụ trách kỹ thuật của công ty cung cấp dịch vụ để yêu cầu có extension «GD» hay «Imagick».</i>', # MODIF
	'info_images_auto' => 'Hình được tự tính',
	'info_informations_personnelles' => 'Bước thứ năm: <b>Dữ kiện cá nhân</b>',
	'info_inscription_automatique' => 'Tự động ghi danh các chủ bút mới',
	'info_jeu_caractere' => 'Bảng mã của website',
	'info_jours' => 'ngày',
	'info_laisser_champs_vides' => 'để trống những phần này)',
	'info_langues' => 'Ngôn ngữ của website',
	'info_ldap_ok' => 'Đặc điểm xác nhận LDAP được thiết trí.',
	'info_lien_hypertexte' => 'Điểm kết nối:',
	'info_liste_redacteurs_connectes' => 'Danh sách các chủ bút đang nối vào',
	'info_login_existant' => 'Login này đã có.',
	'info_login_trop_court' => 'Login ngắn quá.',
	'info_maximum' => 'tối đa:',
	'info_meme_rubrique' => 'Cũng đề mục',
	'info_message_en_redaction' => 'Thư tín đang soạn',
	'info_message_technique' => 'Thư tín kỹ thuật:',
	'info_messagerie_interne' => 'Tin tức nội bộ',
	'info_mise_a_niveau_base' => 'Nâng cấp database SQL',
	'info_mise_a_niveau_base_2' => '{{Cảnh báo!}}Bạn vừa thiết trí một ấn bản SPIP cũ hơn ấn bản thiết trí trước đây: database của bạn có thể gặp rủi ro mất mát và webiste không hoạt động đúng nữa.{{Tái thiết trí các hồ sơ SPIP.}} ',
	'info_modifier_rubrique' => 'Sửa đổi đề mục:',
	'info_modifier_titre' => 'Sửa đổi: @titre@',
	'info_mon_site_spip' => 'Website SPIP của tôi',
	'info_moyenne' => 'trung bình: ',
	'info_multi_cet_article' => 'Bài tiếng:',
	'info_multi_langues_choisies' => 'Xin chọn ngôn ngữ có sẵn cho các chủ bút.
  Ngôn ngữ đã dùng cho trang web thì không tắt được.',
	'info_multi_secteurs' => '... chỉ dành cho các đề mục ở gốc trang web ?',
	'info_nom' => 'Tên',
	'info_nom_destinataire' => 'Tên người nhận',
	'info_nom_site' => 'Tên website của bạn',
	'info_nombre_articles' => '@nb_articles@ bài,',
	'info_nombre_rubriques' => '@nb_rubriques@ đề mục, ',
	'info_nombre_sites' => '@nb_sites@ website, ',
	'info_non_deplacer' => 'Đừng dời...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP có thể thường xuyên gửi tin tức thông báo của website (bài và tin vừa đăng tải).',
	'info_non_envoi_liste_nouveautes' => 'Đừng gửi danh sách tin mới nhất',
	'info_non_modifiable' => 'không thể sửa đổi được',
	'info_non_suppression_mot_cle' => 'Tôi không muốn xóa từ then chốt này.',
	'info_notes' => 'Chú thích',
	'info_nouvel_article' => 'Bài mới',
	'info_nouvelle_traduction' => 'Bản dịch mới:',
	'info_numero_article' => 'SỐ THỨ TỰ BÀI:',
	'info_obligatoire_02' => '[Bắt buộc] ', # MODIF
	'info_option_accepter_visiteurs' => 'Cho phép khách ghi danh từ trang công cộng',
	'info_option_ne_pas_accepter_visiteurs' => 'Từ chối khách ghi danh',
	'info_options_avancees' => 'ĐẶC TÍNH PHỤ TRỘI',
	'info_ou' => 'hoặc... ',
	'info_page_interdite' => 'Trang cấm vào',
	'info_par_nombre_article' => '(theo số lượng bài) ',
	'info_passe_trop_court' => 'Mật mã ngắn quá.',
	'info_passes_identiques' => 'Hai mật mã không giống hệt nhau.',
	'info_plus_cinq_car' => 'hơn 5 mẫu tự',
	'info_plus_cinq_car_2' => '(Hơn 5 mẫu tự) ',
	'info_plus_trois_car' => '(Hơn 3 mẫu tự) ',
	'info_popularite' => 'Mức phổ thông: @popularite@; lần viếng: @visites@',
	'info_post_scriptum' => 'Tái bút',
	'info_post_scriptum_2' => 'Tái bút:',
	'info_pour' => 'cho',
	'info_preview_texte' => 'Bạn có thể xem trước trang web mà các bài vở, tin ngắn (với tình trạng "được đăng") trong đó như đã được cho đăng lên chính thức. Dạng xem trước này chỉ nên giới hạn cho quản trị viên, cho tất cả các tác giả, hay hoàn toàn tắt nó đi ?', # MODIF
	'info_procedez_par_etape' => 'Xin tiếp diễn từng bước một',
	'info_procedure_maj_version' => 'Quy trình nâng cấp cần được chạy để database thích ứng với ấn bản SPIP mới.',
	'info_ps' => 'Tái bút.', # MODIF
	'info_publier' => 'đăng tải',
	'info_publies' => 'Bài của bạn được đăng online',
	'info_question_accepter_visiteurs' => 'Nếu trang web cho phép khách ghi danh mà không cần phải vào vùng riêng, thì xin hãy mở lên những chọn lựa sau:',
	'info_question_inscription_nouveaux_redacteurs' => 'Bạn có cho phép ghi danh các chủ bút mới từ website công cộng không? Nếu đồng ý, khách có thể ghi danh qua một mẫu tự động, và sẽ được phép vào vùng riêng của họ để soạn bài. <blockquote><i>Trong quá trình ghi danh, người dùng sẽ nhận được email cho biết login/mật mã vào chỗ riêng của họ. Một số máy chủ tắt đặc điểm này: trong trường hợp đó, ghi danh tự động không dùng được.</i>', # MODIF
	'info_racine_site' => 'Gốc của website',
	'info_recharger_page' => 'Xin nạp lại trang này trong giây lát.',
	'info_recherche_auteur_zero' => 'Không có kết quả cho "@cherche_auteur@".',
	'info_recommencer' => 'Xin thử lại.',
	'info_redacteur_1' => 'Tác giả',
	'info_redacteur_2' => ' có lối vào vùng tư (<i>đề nghị</i>)',
	'info_redacteurs' => 'Chủ bút',
	'info_redaction_en_cours' => 'ĐANG SOẠN',
	'info_redirection' => 'Chuyển hướng',
	'info_refuses' => 'Bài của bạn bị từ chối',
	'info_reglage_ldap' => 'Chọn lựa: <b>Điều chỉnh việc nhập LDAP</b>',
	'info_renvoi_article' => '<b>Chuyển hướng.</b> Bài này nối đến trang: ',
	'info_reserve_admin' => 'Chỉ có quản trị viên mới có thể sửa đổi địa chỉ này.',
	'info_restreindre_rubrique' => 'Giới hạn việc quản trị trong đề mục:',
	'info_resultat_recherche' => 'Kết quả tìm kiếm:',
	'info_rubriques' => 'Đề mục',
	'info_rubriques_02' => 'đề mục',
	'info_rubriques_trouvees' => 'Tìm thấy đề mục',
	'info_sans_titre' => 'Không tựa đề',
	'info_selection_chemin_acces' => '<b>Chọn</b> dưới đây đường vào trong thư mục:',
	'info_signatures' => 'chữ ký',
	'info_site' => 'Website',
	'info_site_2' => 'website: ',
	'info_site_min' => 'website',
	'info_site_reference_2' => 'Website nối kết',
	'info_site_web' => 'WEB SITE:', # MODIF
	'info_sites' => 'website',
	'info_sites_lies_mot' => 'Những website nối kết liên đới với từ then chốt này',
	'info_sites_proxy' => 'Dùng một proxy',
	'info_sites_trouves' => 'Tìm thấy website',
	'info_sous_titre' => 'Tựa đề phụ:',
	'info_statut_administrateur' => 'Quản trị viên',
	'info_statut_auteur' => 'Quyền hạn của tác giả:', # MODIF
	'info_statut_redacteur' => 'Chủ bút',
	'info_statut_utilisateurs_1' => 'Trạng thái định sẵn của người dùng được đưa vào',
	'info_statut_utilisateurs_2' => 'Chọn trạng thái cho những người liệt kê trong thư mục LDAP khi họ nối vào lần đầu. Về sau, bạn có thể sửa đổi trị giá này cho từng tác giả theo từng trường hợp một.',
	'info_suivi_activite' => 'Thông tin cho Ban Biên Tập',
	'info_surtitre' => 'Đầu đề:',
	'info_taille_maximale_vignette' => 'Kích thước tối đa của hình mẫu:',
	'info_terminer_installation' => 'Bạn có thể kết thúc quy trình thiết trí căn bản.',
	'info_texte' => 'Thân bài',
	'info_texte_explicatif' => 'Giảng giải',
	'info_texte_long' => 'Văn tự quá dài: nó sẽ được cho xem qua nhiều phần và được gôm ại sau khi được chấp thuận.)',
	'info_texte_message' => 'Thân bài:', # MODIF
	'info_texte_message_02' => 'Thân bài',
	'info_titre' => 'Tựa đề:',
	'info_total' => 'tổng cộng: ',
	'info_tous_articles_en_redaction' => 'Tất cả bài vở đang được soạn',
	'info_tous_articles_presents' => 'Tất cả bài vở đã phát hành trong đề mục này',
	'info_tous_les' => 'mỗi:',
	'info_tout_site' => 'Toàn bộ website',
	'info_tout_site2' => 'Bài nầy chưa được dịch qua ngôn ngữ nầy.',
	'info_tout_site3' => 'Bài nầy đã được dịch qua ngôn ngữ nầy rồi, nhưng bài gốc đã được sửa. Các bản dịch cần được cập nhật.  ',
	'info_tout_site4' => 'Bài nầy đã được dịch qua ngôn ngữ nầy rồi, và bản dịch đã được cập nhật.',
	'info_tout_site5' => 'Bài gốc.',
	'info_tout_site6' => '<b>Ghi chú: :</b> chỉ có bài gốc mới hiện ra trong trang này.
Bài dịch sẽ được liên đới với bài gốc,
và hiển ra với những màu khác nhau tùy theo tình trạng bài vở :',
	'info_travail_colaboratif' => 'Sửa đổi/Soạn bài chung với nhau',
	'info_un_article' => 'một bài, ',
	'info_un_site' => 'một website, ',
	'info_une_rubrique' => 'một đề mục, ',
	'info_une_rubrique_02' => '1 đề mục',
	'info_url' => 'URL:', # MODIF
	'info_urlref' => 'Nối kết:',
	'info_utilisation_spip' => 'SPIP sẵn sàng để sử dụng...',
	'info_visites_par_mois' => 'Hiển thị hàng tháng:',
	'info_visiteur_1' => 'Khách',
	'info_visiteur_2' => ' của website công',
	'info_visiteurs' => 'Khách',
	'info_visiteurs_02' => 'Khách của website công',
	'install_echec_annonce' => 'Phần cài đặt này có thể gặp trở ngại, hoặc khiến website hoạt động không hoàn chỉnh...',
	'install_extension_mbstring' => 'SPIP không hoạt động với:',
	'install_extension_php_obligatoire' => 'SPIP cần một bộ phận php:',
	'install_select_langue' => 'Chọn một ngôn ngữ, rồi bấm vào nút "Kế tiếp" để bắt đầu thể thức thiết trí.',
	'intem_redacteur' => 'chủ bút',
	'item_accepter_inscriptions' => 'Cho phép ghi danh',
	'item_activer_messages_avertissement' => 'Cho phép cảnh báo',
	'item_administrateur_2' => 'quản lý',
	'item_afficher_calendrier' => 'Hiện ra trong lịch',
	'item_choix_administrateurs' => 'quản trị viên',
	'item_choix_generation_miniature' => 'Tự động tạo ra các hình mẫu.',
	'item_choix_non_generation_miniature' => 'Đừng tạo ra hình mẫu.',
	'item_choix_redacteurs' => 'chủ bút',
	'item_choix_visiteurs' => 'Khách của website công',
	'item_creer_fichiers_authent' => 'Lập ra hồ sơ .htpasswd',
	'item_login' => 'Login',
	'item_mots_cles_association_articles' => 'bài vở',
	'item_mots_cles_association_rubriques' => 'các đề mục',
	'item_mots_cles_association_sites' => 'Website nối kết hay syndicated.',
	'item_non' => 'Không dùng',
	'item_non_accepter_inscriptions' => 'Không cho phép ghi danh',
	'item_non_activer_messages_avertissement' => 'Không cần cảnh báo',
	'item_non_afficher_calendrier' => 'Không hiện ra trong lịch',
	'item_non_creer_fichiers_authent' => 'Đừng lập ra các hồ sơ này',
	'item_non_publier_articles' => 'Không đăng tải bài trước ngày được phép đăng.',
	'item_nouvel_auteur' => 'Tác giả mới',
	'item_nouvelle_rubrique' => 'Đề mục mới',
	'item_oui' => 'Dùng',
	'item_publier_articles' => 'Cứ đăng tải bài bất kể ngày ghi.',
	'item_reponse_article' => 'Hồi đáp bài ',
	'item_visiteur' => 'khách',

	// J
	'jour_non_connu_nc' => 'k.b.',

	// L
	'lien_ajouter_auteur' => 'Thêm tác giả này',
	'lien_email' => 'email',
	'lien_nom_site' => 'TÊN WEBSITE:',
	'lien_retirer_auteur' => 'Loại bỏ tác giả',
	'lien_site' => 'website',
	'lien_tout_deplier' => 'Mở ra tất cả',
	'lien_tout_replier' => 'Gộp tất cả lại',
	'lien_trier_nom' => 'Xếp theo tên',
	'lien_trier_nombre_articles' => 'Sắp thứ tự theo số bài',
	'lien_trier_statut' => 'Sắp thứ tự theo tình trạng',
	'lien_voir_en_ligne' => 'XEM ONLINE :',
	'logo_article' => 'LOGO CỦA BÀI', # MODIF
	'logo_auteur' => 'LOGO CỦA TÁC GIẢ', # MODIF
	'logo_rubrique' => 'LOGO CỦA ĐỀ MỤC', # MODIF
	'logo_site' => 'LOGO CỦA WEBSITE NÀY', # MODIF
	'logo_standard_rubrique' => 'LOGO CỦA ĐỀ MỤC', # MODIF
	'logo_survol' => 'LOGO NỔI', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'Chọn database của bạn',
	'module_fichier_langue' => 'Hồ sơ ngôn ngữ',
	'module_raccourci' => 'Lối tắt',
	'module_texte_affiche' => 'Văn bản hiển thị',
	'module_texte_explicatif' => 'Bạn có thể thêm các lối tắt sau đây vào mẫu của trang web. Chúng sẽ được tự động dịch qua các ngôn ngữ khác (nếu có hồ sơ ngôn ngữ đó).',
	'module_texte_traduction' => 'Hồ sơ ngôn ngữ « @module@ » này có bằng tiếng:',
	'mois_non_connu' => 'không nhận ra tháng này được',

	// O
	'onglet_repartition_actuelle' => 'hiện nay',

	// R
	'required' => '[Bắt buộc] ', # MODIF

	// S
	'statut_admin_restreint' => '(Quản trị viên có giới hạn)', # MODIF

	// T
	'taille_cache_image' => 'Các hình được tính toán tự động bởi SPIP (hình nhỏ, tựa đề được đổi thành hình, công thức toán học dưới dạng TeX, v.v...) chiếm tổng cộng @taille@ trong ngăn @dir@.',
	'taille_cache_infinie' => 'Trang web không có giới hạn khổ của ngăn <code>CACHE/</code>.', # MODIF
	'taille_cache_maxi' => 'SPIP sẽ giới hạn khổ của ngăn <code>CACHE/</code> vào khoảng <b>@octets@</b> dữ liệu.', # MODIF
	'taille_cache_octets' => 'Khổ của cache hiện thời là @octets@.', # MODIF
	'taille_cache_vide' => 'Cache trống rỗng.',
	'taille_repertoire_cache' => 'Khổ hiện thời của cache',
	'text_article_propose_publication' => 'Bài nộp để chuẩn bị phát hành. Xin đừng ngần ngại cho ý kiến của bạn qua diễn đàn đính kèm theo bài này (ở cuối trang).', # MODIF
	'texte_acces_ldap_anonyme_1' => 'Một số server LDAP không cho phép vào ẩn danh. Trong trường hợp này bạn phải dùng một ký danh đầu tiên để có thể đi tìm tòi dữ kiện trong danh bạ sau đó. Tuy nhiên, trong hầu hết trường hợp, những khoảng sau đây có thể để trống.',
	'texte_admin_effacer_01' => 'Mệnh lệnh này xóa <i>tất cả</i> nội dung của database, luôn cả login/mật mã của các chủ bút và quản lý. Sau khi chạy mệnh lệnh này xong, bạn nên thiết trí lại SPIP để tái lập lại một database mới cùng với login/mật mã của quản trị viên đầu tiên.',
	'texte_adresse_annuaire_1' => '(Nếu ngăn của bạn được thiết trí trên cùng máy với website của bạn, tên nó thường là «localhost».)',
	'texte_ajout_auteur' => 'Tác giả sau đây được thêm vào cho bài: ',
	'texte_annuaire_ldap_1' => 'Nếu bạn vào được một danh bạ (LDAP), bạn có thể dùng nó để nhập vào tự động những người sử dụng trong SPIP.',
	'texte_article_statut' => 'Tình trạng bài vở:',
	'texte_article_virtuel' => 'Bài ảo',
	'texte_article_virtuel_reference' => '<b>Bài ảo:</b> chỉ vào một bài khác trong SPIP của bạn, nhưng chuyển qua một địa chỉ khác. Để loại bỏ việc chuyển qua, xóa địa chỉ URL trên.',
	'texte_aucun_resultat_auteur' => 'Không có kết quả cho "@cherche_auteur@".',
	'texte_auteur_messagerie' => 'Website này có thể giám sát liên tục danh sách những chủ bút đang vào, và cho phép bạn trao đổi thư tín ngay lập tức (nếu hệ thư tín bị tắt thì danh sách các chủ bút đang vào cũng bị tắt theo). Bạn có thể chọn không xuất hiện trong danh sách này (đối với những người khác, bạn sẽ «vô hình»).',
	'texte_auteurs' => 'TÁC GIẢ',
	'texte_choix_base_1' => 'Chọn database của bạn:',
	'texte_choix_base_2' => 'Server SQL chứa nhiều database.',
	'texte_choix_base_3' => '<b>Chọn</b> một trong số dưới đây thuộc về bạn:',
	'texte_compte_element' => '@count@ món',
	'texte_compte_elements' => '@count@ món',
	'texte_connexion_mysql' => 'Xem lại tài liệu cung cấp bởi máy chủ: nếu dùng SQL, máy chủ cho bạn mã số ra vào server SQL. ', # MODIF
	'texte_contenu_article' => '(Mô tả ngắn gọn nội dung của bài) ',
	'texte_contenu_articles' => 'Dựa vào cấu trúc chọn lựa cho website này, bạn có thể quyết định những phần nào của bài vở không cần dùng. Chiếu theo danh sách dưới đây để chọn những phần nào của bài vở dùng được.',
	'texte_crash_base' => 'Nếu database bị hư, bạn có thể tìm cách sửa chữa tự động.',
	'texte_creer_rubrique' => 'Để viết bài,<br />bạn phải lập ra một đề mục. ',
	'texte_date_creation_article' => 'NGÀY VIẾT BÀI:',
	'texte_date_publication_anterieure' => 'Ngày phát hành truớc đó :',
	'texte_date_publication_anterieure_nonaffichee' => 'Dấu ngày phát hành trước đó.',
	'texte_date_publication_article' => 'NGÀY ĐĂNG TẢI ONLINE :',
	'texte_descriptif_rapide' => 'Tóm lược',
	'texte_effacer_base' => 'Xóa database SPIP',
	'texte_en_cours_validation' => 'Bài vở và tin ngắn sau đây được nộp để chờ phát hành. Xin góp ý qua diễn đàn đính kèm. ', # MODIF
	'texte_enrichir_mise_a_jour' => 'Bạn có thể trình bày văn bản gọn đẹp hơn bằng cách dùng những <b>«lối xếp bài tắt»</b>.',
	'texte_fichier_authent' => 'SPIP có nên lập ra hồ sơ đặc biệt <tt>.htpasswd</tt> và <tt>.htpasswd-admin</tt> trong thư mục @dossier@?</b><p> Hai hồ sơ này dùng để giới hạn các tác giả và quản lý viên ra/vào các nơi khác trong website.<p>Nếu bạn chưa từng sử dụng đặc tính này, hãy để nguyên lựa chọn này với các giá trị định sẵn (không lập ra hồ sơ). ', # MODIF
	'texte_informations_personnelles_1' => 'Hệ thống sẽ cung cấp cho bạn lối ra/vào website.',
	'texte_informations_personnelles_2' => '(Ghi chú: nếu đây là tái thiết trí, và việc ra/vào của bạn vẫn bình thường, bạn tiếp tục vậy ', # MODIF
	'texte_introductif_article' => '(Lời mở đầu cho bài viết.) ',
	'texte_jeu_caractere' => 'Chọn lựa này thích hợp nếu website bạn dùng ngôn ngữ khác với mẫu tự latinh (tức "western") và các ngôn ngữ cùng hệ.
 Trong trường hợp này, phải chọn một bộ mã khác. Và cũng nên nhớ sửa đổi website để thích ứng (<tt>#CHARSET</tt> tag).', # MODIF
	'texte_login_ldap_1' => '(Để trống nếu muốn ra/vào ẩn danh hoặc cho biết trọn vẹn lộ tuyến, lấy thí dụ «<tt>uid=smith, ou=users, dc=my-domain, dc=com</tt>».)',
	'texte_login_precaution' => 'Cảnh báo! Đây là login bạn dùng để vào. Dùng mẫu này cẩn thận...',
	'texte_mise_a_niveau_base_1' => 'Bạn vừa cập nhật hồ sơ SPIP. Bây giờ bạn phải nâng cấp database của website.',
	'texte_modifier_article' => 'Sửa bài:',
	'texte_multilinguisme' => 'Nếu bạn muốn quản trị các bài vỡ này trong nhiều ngôn ngữ, bạn có thể thêm vào bài/đề mục một mục lục chọn ngôn ngữ.', # MODIF
	'texte_multilinguisme_trad' => 'Đồng thời, bạn có thể mở lên một hệ thống quản trị cho các bản dịch của một bài.', # MODIF
	'texte_non_compresse' => '<i>Giản ra</i> (server của bạn không dùng đặc tính này)',
	'texte_nouvelle_version_spip_1' => 'Bạn vừa thiết trí ấn bản mới của SPIP.',
	'texte_nouvelle_version_spip_2' => 'Ấn bản mới này cần cập nhật
 kỹ lưởng hơn bình thường.
 Nếu bạn là webmaster, hãy xóa hồ sơ
 <tt>inc_connect.php3</tt> trong ngăn <tt>ecrire</tt>
 và cho thiết trí lại để cập nhật
 những số liệu móc nối vào database.
 <p>(TB.: nếu bạn quên mất số liệu móc nối
 xem lại hồ sơ <tt>inc_connect.php3</tt>
 trước khi xóa ...)', # MODIF
	'texte_operation_echec' => 'Trở lại trang trước đó, chọn database khác hoặc lập ra database mới. Kiểm lại các dữ kiện máy chủ cung cấp.',
	'texte_plus_trois_car' => ' hơn 3 mẫu tự',
	'texte_plusieurs_articles' => 'Tìm thấy nhiều tác giả cho "@cherche_auteur@":',
	'texte_port_annuaire' => 'Giá trị cho sẵn thường phù hợp.',
	'texte_proposer_publication' => 'Khi soạn bài xong,<br />bạn nộp vào để chờ được đăng lên.',
	'texte_proxy' => 'Trong một số trường hợp (intranet, mạng được bảo vệ ...), cần thiết phải dùng <i>proxy HTTP</i> để với tới các website syndicated. Nếu có proxy, cho địa chỉ vào dưới đây, 
<tt><html>http://proxy:8080</html></tt>. Thường thì bạn để khung này trống.',
	'texte_publication_articles_post_dates' => 'SPIP sẽ làm gì khi một bài viết có đề ngày đăng tải sắp tới (trong tương lai)?',
	'texte_rappel_selection_champs' => '[Nhớ chọn phần này cho đúng]',
	'texte_recalcul_page' => 'Nếu bạn chỉ muốn làm mới lại một trang thôi, thì nên làm lại từ vùng công cộng và bấm vào nút «refresh» hay «reload».',
	'texte_recuperer_base' => 'Sữa chữa database',
	'texte_reference_mais_redirige' => 'Bài nối kết trong website SPIP, nhưng chuyển hướng qua địa chỉ URL khác.',
	'texte_requetes_echouent' => '<b>Khi một số hỏi-đáp SQL trượt hàng loạt và có vẻ như không có lý do gì cả, điều đó cho thấy có thể chính database là thủ phạm. </b><p>SQL có một đặc điểm sửa chữa các bản của nó khi chúng bị hư hại. Bạn có thể thử dùng đặc điểm sửa chữa này, trong trường hợp thất bại, bạn nên giữ lại một bản sao của màn ảnh để giúp soi sáng vấn đề ... <p> Nếu vấn đề vẫn tiếp tục xảy ra, liên lạc với chủ nhân của máy.', # MODIF
	'texte_selection_langue_principale' => 'Bạn chọn một "ngôn ngữ chính" sau đây cho website. Điều này không có nghĩa là bạn chỉ có thể dùng ngôn ngữ đó cho các bài vở, mà bạn muốn dùng ngôn ngữ nào trong bài cũng được. Chọn ngôn ngữ chính cho web site chỉ để
<ul>
<li> chọn cách ghi ngày tháng cho phù hợp với ngôn ngữ đã chọn</li>
<li> giúp cơ phận trình bày của SPIP biết cách trình bày văn tự của bài vở cho đúng cách.</i>
<li> ngôn ngữ dùng trong các mẫu đơn của website</i>
<li> ngôn ngữ chính hiển trị trong các vùng riêng</li>
</ul>',
	'texte_sous_titre' => 'Tựa đề phụ',
	'texte_statistiques_visites' => 'Thah đậm: Chủ nhật / vòng cong đậm: đợt trung bình)',
	'texte_statut_attente_validation' => 'đang chờ chấp thuận',
	'texte_statut_publies' => 'được đăng lên',
	'texte_statut_refuses' => 'bị từ chối',
	'texte_suppression_fichiers' => 'Dùng mệnh lệnh này để xóa tất cả hồ sơ trong SPIP cache. Làm vậy để buộc làm mới lại mọi trang web, trong trường hợp bạn vừa có một số thay đổi về đồ họa hay cấu trúc của website.',
	'texte_sur_titre' => 'Đầu đề',
	'texte_table_ok' => ': bản này OK.',
	'texte_tentative_recuperation' => 'Tìm cách sửa chữa',
	'texte_tenter_reparation' => 'Tìm cách sửa chữa database',
	'texte_test_proxy' => 'Để thử proxy này, đánh vào địa chỉ một website bạn muốn thử.',
	'texte_titre_02' => 'Tựa đề:',
	'texte_titre_obligatoire' => '<b>Tựa đề</b> [Bắt buộc] ',
	'texte_travail_article' => '@nom_auteur_modif@ đã soạn/bổ túc bài này cách đây @date_diff@ phút',
	'texte_travail_collaboratif' => 'Nếu có nhiều người cùng soạn/sửa đổi một bài, hệ thống có thể cho thấy những bài đang được «làm việc» để tránh trường hợp sửa đổi cùng một lúc. 
Bạn có thể cho phép cảnh báo hay không:',
	'texte_vide' => 'Trống rỗng',
	'texte_vider_cache' => 'Dọn sạch cache',
	'titre_admin_tech' => 'Bảo trì kỹ thuật',
	'titre_admin_vider' => 'Bảo trì kỹ thuật',
	'titre_cadre_afficher_article' => 'Liệt kê những bài',
	'titre_cadre_afficher_traductions' => 'Cho xem tình trạng dịch thuật của ngôn ngữ này.',
	'titre_cadre_ajouter_auteur' => 'THÊM MỘT TÁC GIẢ:',
	'titre_cadre_interieur_rubrique' => 'Trong đề mục',
	'titre_cadre_numero_auteur' => 'SỐ THỨ TỰ TÁC GIẢ',
	'titre_cadre_signature_obligatoire' => '<b>Danh tánh</b> [Bắt buộc]<br />',
	'titre_config_fonctions' => 'Cấu hình của website',
	'titre_configuration' => 'Cấu hình của website',
	'titre_connexion_ldap' => 'Tùy chọn: <b>Kết nối vào LDAP</b>',
	'titre_groupe_mots' => 'NHÓM TỪ THEN CHỐT:',
	'titre_langue_article' => 'NGÔN NGỮ CỦA BÀI', # MODIF
	'titre_langue_rubrique' => 'NGÔN NGỮ CỦA ĐỀ MỤC', # MODIF
	'titre_langue_trad_article' => 'NGÔN NGỮ VÀ DỊCH THUẬT CỦA BÀI',
	'titre_les_articles' => 'BÀI VỞ',
	'titre_naviguer_dans_le_site' => 'Xem trang web...',
	'titre_nouvelle_rubrique' => 'Đề mục mới',
	'titre_numero_rubrique' => 'SỐ THỨ TỰ ĐỀ MỤC:',
	'titre_page_articles_edit' => 'Bổ túc: @titre@',
	'titre_page_articles_page' => 'Bài vỡ',
	'titre_page_articles_tous' => 'Toàn bộ trang web',
	'titre_page_calendrier' => 'Lịch @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Cấu hình website',
	'titre_page_delete_all' => 'xóa luôn và không lấy lại được',
	'titre_page_recherche' => 'Kết quả tìm kiếm @recherche@',
	'titre_page_statistiques_referers' => 'Thống kê (các điểm nối vào)',
	'titre_page_upgrade' => 'nâng cấp SPIP',
	'titre_publication_articles_post_dates' => 'Đăng tải bài vở có đề ngày',
	'titre_reparation' => 'Sửa chữa',
	'titre_suivi_petition' => 'Quản trị Thỉnh nguyện thư',
	'trad_article_traduction' => 'Tất cả ấn bản của bài này:',
	'trad_delier' => 'Đừng nối bài này qua bản dịch', # MODIF
	'trad_lier' => 'Bài này là bản dịch của bài số',
	'trad_new' => 'Dịch bài này' # MODIF
);

?>
